@@ -6,7 +6,7 @@ use warnings;
 use AnyEvent;
 use AnyEvent::RipeRedis;
 
-my $cv = AE::cv();
+my $cv = AE::cv;
 
 my $redis;
 $redis = AnyEvent::RipeRedis->new(
@@ -47,12 +47,12 @@ $timer = AE::timer( 0, 1,
 
 my $on_signal = sub {
   print "Stopped\n";
-  $cv->send();
+  $cv->send;
 };
 
 my $int_w  = AE::signal( INT  => $on_signal );
 my $term_w = AE::signal( TERM => $on_signal );
 
-$cv->recv();
+$cv->recv;
 
-$redis->disconnect();
+$redis->disconnect;
